package com.factory.web.service.impl.pm;

import java.util.List;
import java.util.function.Function;

import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.factory.base.entity.aggregates.PageBean;
import com.factory.base.entity.aggregates.ResponseBean;
import com.factory.base.entity.po.benteler.BentelerPlan;
import com.factory.base.util.res.ResponseBeanBuilder;
import com.factory.web.entity.pm.PreventMistakePlanListReq;
import com.factory.web.entity.pm.PreventMistakePlanListRes;
import com.factory.web.mapper.pm.PreventMistakeMapper;
import com.factory.web.service.BentelerPlanService;
import com.factory.web.service.pm.PreventMistakeService;

/**
 * 防错计划
 *
 * @author wzy
 * @date 2021-07-09 12:00:00
 */
@Service("preventMistakeService")
@Transactional(rollbackFor = Exception.class)
public class PreventMistakeServiceImpl extends ServiceImpl<PreventMistakeMapper, BentelerPlan> implements PreventMistakeService {

	@Autowired
    private PreventMistakeMapper preventMistakeMapper;
	
    @Autowired
    private BentelerPlanService planService;
    
    /**
     * 计划名称是否重复
     * @param name
     * @return 
     */
    @Override
    public boolean planNameRepetition(String name) {
        List<BentelerPlan> plans = planService.list(Wrappers.<BentelerPlan>lambdaQuery()
                .eq(BentelerPlan::getName, name));
        if (CollectionUtils.isNotEmpty(plans)) {
            return true;
        }
        return false;
    }

    /**
     * 取得巡检项目列表
     * @param req
     * @return 巡检项目列表
     */
    @Override
    public ResponseBean<PageBean<PreventMistakePlanListRes>> getPreventMistakePlanList(PreventMistakePlanListReq req) {
    	Page<PreventMistakePlanListRes> page = new Page<>(req.getPage(), req.getSize());
        Page<PreventMistakePlanListRes> listResPage = preventMistakeMapper.getPreventMistakePlanList(page, req);
        return ResponseBeanBuilder.ok(listResPage, Function.identity());
    }

    
}